import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

import 'key_listner_action.dart';
import 'key_listner_intent.dart';

class KeyListner<T> extends StatelessWidget {
  const KeyListner({
    Key? key,
    required this.child,
    this.keyDownAction,
    this.keyUpAction,
    required this.keyboardKey,
  }) : super(key: key);

  final Widget child;
  final KeyListnerAction? keyDownAction;
  final KeyListnerAction? keyUpAction;
  final LogicalKeyboardKey keyboardKey;

  @override
  Widget build(BuildContext context) {
    final Map<Type, Action<Intent>> actions = {};
    if (keyDownAction != null) {
      actions.addAll({keyDownAction!.intent.runtimeType: keyDownAction!.action});
    }
    if (keyUpAction != null) {
      actions.addAll({keyUpAction!.intent.runtimeType: keyUpAction!.action});
    }

    return Focus(
      autofocus: true,
      child: Actions(
        actions: actions,
        child: Builder(builder: (context) {
          return KeyboardListener(
            onKeyEvent: (value) async {
              if (keyboardKey != value.logicalKey) {
                return;
              } else if (value is KeyRepeatEvent) {
                return;
              } else if (value is KeyDownEvent && keyDownAction != null) {
                // final k = KeyListnerAction(keyDownAction);
                Actions.invoke(context, keyDownAction!.intent);
                // Actions.invoke(context, KeyDownListnerIntent(context, value.logicalKey));
                // k.invoke(KeyDownListnerIntent(context, value.logicalKey));
              } else if (value is KeyUpEvent && keyUpAction != null) {
                Actions.invoke(context, keyUpAction!.intent);
                // final k = KeyListnerAction(keyUpAction);
                // k.invoke(ScreenshotIntent(context));
                // Actions.invoke(context, KeyUpListnerIntent(context, value.logicalKey));
              }
            },
            focusNode: FocusNode(),
            child: child,
          );
        }),
      ),
    );
  }
}
